@@ -1,5 +1,6 @@
 import hashlib
 import heapq
+import random
 import time
 from functools import wraps
 import json as Json
@@ -356,6 +357,20 @@ def args_split(args: tuple):
     return arg, kwarg or {}
 
 
+def random_list(stop, start=0, step=1):
+    numbers = list(range(start, stop, step))
+    random.shuffle(numbers)
+    return numbers
+
+
+def human_time(time_stamp):
+    days = time_stamp // 86400
+    hours = (time_stamp % 86400) // 3600
+    minutes = (time_stamp % 3600) // 60
+    seconds = (time_stamp % 60)
+    return days, hours, minutes, seconds
+
+
 class DictFactory(object):
     def __init__(self, data):
         assert isinstance(data, dict), 'item must be a dict'
